@@ -77,6 +77,12 @@ static void
 gtk_source_completion_list_box_row_init (GtkSourceCompletionListBoxRow *self)
 {
 	gtk_widget_init_template (GTK_WIDGET (self));
+
+  gtk_list_box_row_set_header (GTK_LIST_BOX_ROW (self),
+                               g_object_new (GTK_TYPE_SEPARATOR,
+                                             "orientation", GTK_ORIENTATION_HORIZONTAL,
+                                             "visible", FALSE,
+                                             NULL));
 }
 
 GtkWidget *
@@ -138,13 +144,9 @@ get_margin_and_border (GtkWidget *widget,
                        GtkBorder *margin,
                        GtkBorder *border)
 {
-	G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-
 	GtkStyleContext *style_context = gtk_widget_get_style_context (widget);
 	gtk_style_context_get_margin (style_context, margin);
 	gtk_style_context_get_border (style_context, border);
-
-	G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 gint
